<?php

namespace Drupal\signmaker_ui\Plugin\Block;

use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\Language;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;

#[Block(
  id: "signmaker_block",
  admin_label: new TranslatableMarkup("Signmaker Block"),
)]
class SignmakerBlock extends BlockBase {
  public function blockForm($form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();

    /** @var \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager */
    $entity_field_manager = \Drupal::service('entity_field.manager');
    $fields = $entity_field_manager->getFieldStorageDefinitions('media');
    /** @var \Drupal\Core\Field\FieldStorageDefinitionInterface $field */
    $field = $fields['field_refuse_type'];
    $settings = $field->getSettings();

    $form['type'] = [
      '#type' => 'select',
      '#options' => ['' => ' - '] + $settings['allowed_values'],
      "#required" => TRUE,
      '#title' => $this->t('Type'),
      '#default_value' => $config['type'],
    ];
    $form['bbox'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Bounding Box of Images'),
      '#description' => $this->t('Percentage from each side of the background image'),
      'top' => [
        '#type' => 'number',
        '#title' => $this->t('Top'),
        '#required' => TRUE,
        '#default_value' => $config['bbox']['top'] ?? 0,
      ],
      'right' => [
        '#type' => 'number',
        '#title' => $this->t('Right'),
        '#required' => TRUE,
        '#default_value' => $config['bbox']['right'] ?? 0,
      ],
      'bottom' => [
        '#type' => 'number',
        '#title' => $this->t('Bottom'),
        '#required' => TRUE,
        '#default_value' => $config['bbox']['bottom'] ?? 0,
      ],
      'left' => [
        '#type' => 'number',
        '#title' => $this->t('Left'),
        '#required' => TRUE,
        '#default_value' => $config['bbox']['left'] ?? 0,
      ]
    ];

    return $form;
  }

  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['bbox'] = $form_state->getValue('bbox');
    $this->configuration['type'] = $form_state->getValue('type');
  }

  public function build() {
    $config = $this->getConfiguration();
    $na_language = \Drupal::languageManager()->getLanguage(Language::LANGCODE_NOT_APPLICABLE);
    $parameters = [
      'directory' => "files/signmaker/{$config['type']}",
      'bbox' => implode(',', $this->configuration['bbox']),
      'root' => Url::fromRoute('signmaker_ui.main', [], ['absolute' => TRUE, 'language' => $na_language])->toString(),
    ];
    $url = Url::fromRoute('signmaker_ui.main', [], ['absolute' => true, 'query' => $parameters, 'language' => $na_language]);
    return ['content' => [
      '#type' => 'html_tag',
      '#tag' => 'iframe',
      '#attached' => ['library' => ['signmaker_ui/signmaker_embed']],
      '#attributes' => [
        'src' => $url->toString(),
        'width' => '100%',
        'height' => '800px',
        'style' => 'border: 0',
        'class' => ['signmaker-iframe']
      ]
    ]];
  }

}